@@ -1,6 +1,6 @@
 package HTML::Microformats::hMeasure;
 
-use base qw(HTML::Microformats::BASE);
+use base qw(HTML::Microformats::BASE HTML::Microformats::Mixin::Parser);
 use common::sense;
 use 5.008;
 
@@ -453,4 +453,4 @@ sub format_signature
 		};
 }
 
-1;
\ No newline at end of file
+1;
